@@ -1,7 +1,7 @@
 # $Author: ddumont $
-# $Date: 2007/01/11 12:59:53 $
+# $Date: 2007/05/07 11:46:16 $
 # $Name:  $
-# $Revision: 1.2 $
+# $Revision: 1.3 $
 
 #    Copyright (c) 2005,2006 Dominique Dumont.
 #
@@ -50,7 +50,8 @@
       'Gamma'       =>  { type => 'node', 
 			  config_class_name => 'Xorg::Monitor::Gamma'},
 
-      'UseModes'    => { type => 'check_list',
+      'UseModes'    => { type => 'leaf',
+			 value_type => 'reference' ,
 			 refer_to => '! Modes ',
 		       } ,
       'Mode'        => { type => 'hash',
